@@ -11,7 +11,8 @@ test_that('Thall et al. Scenario 1 decisions are replicated', {
     mu_mean = -1.3863,
     mu_sd = sqrt(1 / 0.1),
     tau_alpha = 2,
-    tau_beta = 20)
+    tau_beta = 20,
+    refresh = 0)
   continue <- colMeans(as.data.frame(mod, 'prob_response') > 0.3) > 0.005
   continue <- unname(continue)
   expect_false(continue[1])
